@@ -1,6 +1,6 @@
 package Apache::VMonitor;
 
-$Apache::VMonitor::VERSION = '0.6';
+$Apache::VMonitor::VERSION = '0.7';
 
 use strict;
 
@@ -153,7 +153,7 @@ sub print_top{
     my $cpu   = $gtop->cpu;
     my $total = $cpu->total;
     printf "<B>CPU:   %2.1f%% user, %2.1f%% nice, %2.1f%% sys, %2.1f%% idle</B>\n",
-        map {$cpu->$_() * 100 / $total} qw(user nice sys idle);
+        map {$total ? ($cpu->$_() * 100 / $total) : 0 } qw(user nice sys idle);
 
     #######################
     # total mem stats
@@ -175,7 +175,7 @@ sub print_top{
 
     my $swap_total = $swap->total;
     my $swap_used  = $swap->used;
-    my $swap_usage = $swap_used * 100 / $swap_total;
+    my $swap_usage = $swap_total ? ($swap_used * 100 / $swap_total) : 0;
 
     # choose format color according to swap occupation
     if (5000 < $swap_used and $swap_used < 10000) {
@@ -1186,7 +1186,7 @@ Apache::VMonitor - Visual System and Apache Server Monitor
   ExtendedStatus On
 
   # Configuration in httpd.conf
-  <Location /sys-monitor>
+  <Location /system/vmonitor>
     SetHandler perl-script
     PerlHandler Apache::VMonitor
   </Location>
@@ -1207,10 +1207,10 @@ Apache::VMonitor - Visual System and Apache Server Monitor
 
 =head1 DESCRIPTION
 
-This module emulates the reporting functionalities of top(), mount(),
-df() and ifconfig() utilities. It has a visual alert capabilities and
-configurable automatic refresh mode. All the sections can be
-shown/hidden dynamically through the web interface. 
+This module emulates the reporting functionalities of top(1), extended
+for mod_perl processes, mount(1), and df(1) utilities. It has a visual
+alerting capabilities and configurable automatic refresh mode. All the
+sections can be shown/hidden dynamically through the web interface.
 
 The are two main modes: 
 
@@ -1223,36 +1223,67 @@ description of the sub-modes below.
 
 =item * Single process mode
 
-An indepth information about a single process is shown.
 
-If the chosen process is an Apache/mod_perl process, the following
-info is displayed:
+If you need to get an indepth information about a single process, you
+just need to click on its PID.
 
-Process type (child or parent), status of the process (starting,
-reading, sending waiting and etc), how long the current request is
-processed or last was processed. 
+If the chosen process is a mod_perl process, the following info is
+displayed:
 
-Bytes transferred and requests served perl child and per slot.
+=over
 
-Cpu times used by process: total, utime, stime, cutime, cstime.
+=item *
 
-For all processes:
+Process type (child or parent), status of the process (I<Starting>,
+I<Reading>, I<Sending>, I<Waiting>, etc.), how long the current
+request is processed or the last one was processed if the process is
+inactive at the moment of the report take.
 
-General process info:
+=item *
 
-UID, GID, State, TTY, Command line args
+How many bytes transferred so far. How many requests served per child
+and per slot.
+
+=item *
+
+CPU times used by process: C<total>, C<utime>, C<stime>, C<cutime>,
+C<cstime>.
+
+=back
+
+For all (mod_perl and non-mod_perl) processes the following
+information is reported:
+
+=over
+
+=item *
+
+General process info: UID, GID, State, TTY, Command line arguments
+
+=item *
 
 Memory Usage: Size, Share, VSize, RSS
 
+=item *
+
 Memory Segments Usage: text, shared lib, date and stack.
 
+=item *
+
 Memory Maps: start-end, offset, device_major:device_minor, inode,
 perm, library path.
 
+=item *
+
 Loaded libraries sizes.
 
 =back
 
+Just like the multi-process mode, this mode allows you to
+automatically refresh the page on the desired intervals.
+
+=back
+
 Other available modes within 'Multi processes mode'.
 
 =over
@@ -1271,16 +1302,18 @@ Note that 0 (zero) turns automatic refreshing off.
 
 =item top(1) emulation (system)
 
-Just like top() it shows current date/time, machine uptime, average
-load, all the system CPU and memory usage: CPU Load, Mem and Swap
-usage.
+Just like top(1) it shows current date/time, machine uptime, average
+load, all the system CPU and memory usage: CPU load, Real memory and
+swap partition usage.
 
-The top() section includes a swap space usage visual alert
+The top(1) section includes a swap space usage visual alert
 capability. The color of the swap report will be changed:
 
-   1) 5Mb < swap < 10 MB             color: light red
-   2) 20% < swap (swapping is bad!)  color: red
-   3) 70% < swap (swap almost used!) color: red + blinking
+         swap usage               report color
+   ---------------------------------------------------------
+   5Mb < swap < 10 MB             light red
+   20% < swap (swapping is bad!)  red
+   70% < swap (almost all used!)  red + blinking (if enabled)
 
 Note that you can turn off blinking with:
 
@@ -1298,35 +1331,48 @@ The default is to display this section.
 
 =item top(1) emulation (Apache/mod_perl processes)
 
-Then just like in real top() there is a report of the processes, but
-it shows all the relevant information about httpd processes only! The
-report includes the status of the process (starting, reading, sending
-waiting and etc), process' id, time since current request was started,
-last request processing time, size, shared, virtual and resident size.
-It shows the last client's IP and Request (only 64 chars, as this is
-the maximum length stored by underlying Apache core library).
+Then just like in real top(1) there is a report of the processes, but
+it shows all the relevant information about mod_perl processes only!
+
+The report includes the status of the process (I<Starting>,
+I<Reading>, I<Sending>, I<Waiting>, etc.), process' ID, time since
+current request was started, last request processing time, size,
+shared, virtual and resident size.  It shows the last client's IP and
+Request URI (only 64 chars, as this is the maximum length stored by
+underlying Apache core library).
 
 You can sort the report by any column, see the
 L<CONFIGURATION|/CONFIGURATION> section for details.
 
-At the end there is a calculation of the total memory being used by
-all httpd processes as reported by kernel, plus a result of an attempt
-to approximately calculate the real memory usage when sharing is in
-place. How do I calculate this:
+The section is concluded with a report about the total memory being
+used by all mod_perl processes as reported by kernel, plus extra
+number, which results from an attempt to approximately calculate the
+real memory usage when memory sharing is taking place. The calculation
+is performed by using the following logic:
 
-1. For each process sum up the difference between shared and system
+=over
+
+=item 1
+
+For each process sum up the difference between shared and total
 memory.
 
-2. Now if we add the share size of the process with maximum
-shared memory, we will get all the memory that actually is being
-used by all httpd processes but the parent process.
+=item 2
 
-Please note that this might be incorrect for your system, so you use
-this number on your own risk. I have verified this number, by writing
-it down and then killing all the servers. The system memory went down
-by approximately this number. Again, use this number wisely!
+Now if we add the share size of the process with maximum shared
+memory, we will get all the memory that is actually used by all
+mod_perl processes, but the parent process.
 
-If you don't want the Apache section to be displayed set:
+=back
+
+Please note that this might be incorrect for your system, so you
+should use this number on your own risk. We have verified this number
+on the Linux OS, by taken the number reported by C<Apache::VMonitor>,
+then stopping mod_perl and looking at the system memory usage. The
+system memory went down approximately by the number reported by the
+tool. Again, use this number wisely!
+
+If you don't want the mod_perl processes section to be displayed set:
 
   $Apache::VMonitor::Config{APACHE} = 0;
 
@@ -1334,32 +1380,29 @@ The default is to display this section.
 
 =item top(1) emulation (any processes)
 
-This section, just like the Apache/mod_perl processes section,
-displays the information in a top(1) fashion. You use a regular
-expression for processes you want to see.
 
-For each group of matched processes, just like with
-Apache/mod_processes a total size and estimation of the real memory
-taken into account the shared memory, is displayed.
-
-If you want the Apache section to be displayed a REGEX for processes
-to match. e.g if you want to see C<http>, C<mysql> and C<squid>
-processes, set:
-
-  $Apache::VMonitor::PROC_REGEX = join "\|", qw(httpd mysql squid);
-
-and
+This section, just like the mod_perl processes section, displays the
+information in a top(1) fashion. To enable this section you have to
+set:
 
   $Apache::VMonitor::Config{PROCS} = 1;
 
 The default is not to display this section.
 
+Now you need to specify which processes are to be monitored. The
+regular expression that will match the desired processes is required
+for this section to work. For example if you want to see all the
+processes whose name include any of these strings: I<http>, I<mysql>
+and I<squid>, the following regular expression is to be used:
+
+  $Apache::VMonitor::PROC_REGEX = join "\|", qw(httpd mysql squid);
+
 =item mount(1) emulation
 
 This section reports about mounted filesystems, the same way as if you
-have called mount() with no parameters.
+have called mount(1) with no parameters.
 
-If you want the mount() section to be displayed set:
+If you want the mount(1) section to be displayed set:
 
   $Apache::VMonitor::Config{MOUNT} = 1;
 
@@ -1367,22 +1410,23 @@ The default is NOT to display this section.
 
 =item df(1) emulation 
 
-This section completely reproduces the df() utility. For each mounted
+This section completely reproduces the df(1) utility. For each mounted
 filesystem it reports the number of total and available blocks (for
 both superuser and user), and usage in percents.
 
-In addition it reports about available and used filenodes in numbers
+In addition it reports about available and used file inodes in numbers
 and percents.
 
 This section has a capability of visual alert which is being triggered
 when either some filesystem becomes more than 90% full or there are
-less 10% of free filenodes left. When that happens the filesystem
-related line will go bold and red and a mounting point will blink if
-the blinking is turned on. You can the blinking off with:
+less than 10% of free file inodes left. When this event happens the
+filesystem related report row will be displayed in the bold font and
+in the red color. A mount point directory will blink if the blinking
+is turned on. You can turn the blinking on with:
 
-  $Apache::VMonitor::Config{BLINKING} = 0;
+  $Apache::VMonitor::Config{BLINKING} = 1;
 
-If you don't want the df() section to be displayed set:
+If you don't want the df(1) section to be displayed set:
 
   $Apache::VMonitor::Config{FS_USAGE} = 0;
 
@@ -1408,17 +1452,32 @@ The default is NOT to display this section.
 To enable this module you should modify a configuration in
 B<httpd.conf>, if you add the following configuration:
 
-  <Location /sys-monitor>
+  <Location /system/vmonitor>
     SetHandler perl-script
     PerlHandler Apache::VMonitor
   </Location>
 
 The monitor will be displayed when you request
-http://localhost/sys-monitor or alike.
+http://localhost/system/vmonitor or alike.
+
+You probably want to protect this location, from unwanted visitors. If
+you are accessing this location from the same IP address, you can use
+a simple host based authentication:
+
+  <Location /system/vmonitor>
+    SetHandler perl-script
+    PerlHandler Apache::VMonitor
+    order deny, allow
+    deny  from all
+    allow from 132.123.123.3
+  </Location>
+
+Alternatively you may use the Basic or other authentication schemes
+provided by Apache and various extensions.
 
 You can control the behavior of this module by configuring the
-following variables in the startup file or inside the B<<Perl>>
-section.
+following variables in the startup file or inside the
+C<E<lt>PerlE<gt>> section.
 
 Module loading:
 
@@ -1439,9 +1498,10 @@ Control over what sections to display:
   $Apache::VMonitor::Config{FS_USAGE} = 1;
 
 Control the sorting of the mod_perl processes report. You can sort
-them by one of the following columns: "pid", "mode", "elapsed",
-"lastreq", "served", "size", "share", "vsize", "rss", "client",
-"request".
+them by one of the following columns: I<"pid">, I<"mode">,
+I<"elapsed">, I<"lastreq">, I<"served">, I<"size">, I<"share">,
+I<"vsize">, I<"rss">, I<"client">, I<"request">. For example to sort
+by the process size the following setting will do:
 
   $Apache::VMonitor::Config{SORT_BY}  = 'size';
 
@@ -1464,8 +1524,8 @@ on the server side.
 
 You need to have B<Apache::Scoreboard> installed and configured in
 I<httpd.conf>, which in turn requires mod_status to be installed. You
-also have to enable the extended status, for this module to work
-properly. In I<httpd.conf> add:
+also have to enable the extended status for mod_status, for this
+module to work properly. In I<httpd.conf> add:
 
   ExtendedStatus On
 
